==> nextcloud-app-news-14.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/el.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Το αίτημα απέτυχε, η σύνδεση στο δίκτυο δεν είναι διαθέσιμη!",
    "Request unauthorized. Are you logged in?" : "Το αίτημα δεν είναι εξουσιοδοτημένο. Είστε συνδεδεμένοι;",
    "Request forbidden. Are you an admin?" : "Το αίτημα δεν επιτράπει. Είστε διαχειριστής;",
    "Token expired or app not enabled! Reload the page!" : "Η διαδικασία αναγνώρισης τερματίστηκε ή η εφαρμογή δεν είναι ενεργοποιημένη! Επαναφορτώστε τη σελίδα! ",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Εσωτερικό σφάλμα διακομιστή! Παρακαλώ ελέγξτε το αρχείο data/nextcloud.log για περισσότερες πληροφορίες!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Αποτυχία αιτήματος, το Nextcloud είναι προσωρινά σε κατάσταση συντήρησης!",
    "Can not add feed: Exists already" : "Αδυναμία προσθήκης ροής: Υπάρχει ήδη",
    "Articles without feed" : "Άρθρα χωρίς ροές",
    "Can not add folder: Exists already" : "Αδυναμία προσθήκης φακέλου: Υπάρχει ήδη",
    "News" : "Νέα",
    "An RSS/Atom feed reader" : "Τροφοδότης ροής RSS/Atom",
    "Use system cron for updates" : "Χρήση του cron του συστήματος για ενημερώσεις",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Απενεργοποιήστε αυτό εάν τρέχετε μια τροποποιημένη υπηρεσία ενημέρωσης όπως την υπηρεσία ενημέρωσης Python που περιλαμβάνεται στην εφαρμογή",
    "Purge interval" : "Διάστημα καθαρισμού",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Η ελάχιστη διάρκεια σε δευτερόλεπτα μετά τη διαγραφή ροών και φακέλων οπότε θα απομακρύνονται από τη βάση δεδομένων - τιμές κάτω από 60 δευτερόλεπτα θα αγνοούνται",
    "Maximum read count per feed" : "Ο μέγιστος αριθμός διαβασμένων ανά ροή",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Ορίζει τη μέγιστη ποσότητα άρθρων που μπορούν να διαβαστούν ανά ροή, τα οποία δεν θα διαγραφούν από την εργασία καθαρισμού; εάν τα παλαιά άρθρα επανεμφανιστούν μετά την ανάγνωσή τους, αυξήστε αυτήν την τιμή; οι αρνητικές τιμές, όπως το -1, θα απενεργοποιήσουν αυτή τη λειτουργία",
    "Maximum redirects" : "Μέγιστος αριθμός ανακατευθύνσεων",
    "How many redirects the feed fetcher should follow" : "Πόσες ανακατευθύνσεις θα πρέπει να ακολουθεί ο δέκτης ροών",
    "Maximum feed page size" : "Μέγιστο μέγεθος σελίδας ροής",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Μέγιστο μέγεθος ροής σε bytes. Εάν η σελίδα RSS/Atom είναι μεγαλύτερη από αυτήν την τιμή, η ενημέρωση θα ματαιωθεί",
    "Feed fetcher timeout" : "Χρόνος λήξης δέκτη ροής",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Μέγιστος αριθμός δευτερολέπτων για αναμονή φόρτωσης μιας ροής RSS ή Atom - εάν πάρει περισσότερη ώρα η ενημέρωση θα ματαιωθεί",
    "Explore Service URL" : "URL Υπηρεσίας Εξερεύνησης",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Εάν οριστεί, η URL αυτής της υπηρεσίας θα ερωτηθεί για την προβολή των ροών στο τμήμα εξερεύνησης ροών. Για να επιστρέψετε πίσω στην ενσωματωμένη υπηρεσία εξερεύνησης, αφήστε αυτή την είσοδο άδεια",
    "For more information check the wiki" : "Για περισσότερες πληροφορίες δείτε στο wiki",
    "Saved" : "Αποθηκεύτηκαν",
    "Download" : "Λήψη",
    "Close" : "Κλείσιμο",
    "filter" : "φίλτρο",
    "Language" : "Γλώσσα",
    "Subscribe" : "Συνδρομή",
    "Got more awesome feeds? Share them with us!" : "Έχετε πιο τρομερές ροές; Μοιραστείτε τα μαζί μας!",
    "No articles available" : "Δεν υπάρχουν διαθέσιμα άρθρα",
    "No unread articles available" : "Κανένα αδιάβαστο άρθρο διαθέσιμο",
    "Open website" : "Άνοιγμα ιστοσελίδας",
    "Star article" : "Επισήμανση με αστέρι",
    "Unstar article" : "Αναίρεση επισήμανσης με αστέρι",
    "Keep article unread" : "Διατήρηση άρθρου ως μη αναγνωσμένου",
    "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη αναγνωσμένου",
    "by" : "από",
    "from" : "από",
    "Play audio" : "Αναπαραγωγή ήχου",
    "Download audio" : "Λήψη ήχου",
    "Download video" : "Κατεβάστε το βίντεο",
    "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
    "Description" : "Περιγραφή",
    "right" : "δεξιά",
    "Jump to next article" : "Επόμενο άρθρο",
    "left" : "αριστερά",
    "Jump to previous article" : "Προηγούμενο άρθρο",
    "Toggle star article" : "Εναλλαγή επισήμανσης άρθρου με αστέρι",
    "Star article and jump to next one" : "Επισήμανση άρθρου και μετακίνηση στο επόμενο",
    "Toggle keep current article unread" : "Εναλλαγή διατήρισης τρέχοντος άρθρου ως μη αναγνωσμένου",
    "Open article in new tab" : "Άνοιγμα άρθρου σε νέα καρτέλα",
    "Toggle expand article in compact view" : "Εναλλαγή επέκτασης άρθρου στη συμπαγή προβολή",
    "Refresh" : "Ανανέωση ",
    "Load next feed" : "Φόρτωση επόμενης ροής",
    "Load previous feed" : "Φόρτωση προηγούμενης ροής",
    "Load next folder" : "Φόρτωση επόμενου φακέλου",
    "Load previous folder" : "Φόρτωση προηγούμενου φακέλου",
    "Scroll to active navigation entry" : "Κύλιση στην ενεργή είσοδο πλοήγησης ",
    "Focus search field" : "Εστίαση στο πεδίο αναζήτησης",
    "Mark current article's feed/folder read" : "Σημείωση της ροής/φακέλου του τρέχοντος άρθρου ως αναγνωσμένα",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
    "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα",
    "Web address" : "Διεύθυνση ιστοσελίδας",
    "Feed exists already!" : "Η ροή υπάρχει ήδη!",
    "Folder" : "Φάκελος",
    "No folder" : "Κανένας φάκελος",
    "New folder" : "Νέος φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "Go back" : "Μετακίνηση πίσω",
    "Folder exists already!" : "Ο φάκελος υπάρχει ήδη!",
    "Credentials" : "Πιστοποιητικά",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Τα διαπιστευτήρια Βασικής Πιστοποίησης HTTP πρέπει να αποθηκεύονται χωρίς κρυπτογράφηση! Όλοι με πρόσβαση στον διακομιστή ή τη βάση δεδομένων θα έχουν πρόσβαση σε αυτά!",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "New Folder" : "Νέος φάκελος",
    "Create" : "Δημιουργία",
    "Explore" : "Εξερεύνηση",
    "Update failed more than 50 times" : "Η αποστολή απέτυχε πάνω από 50 φορές",
    "Deleted feed" : "Διαγραφή ροής",
    "Undo delete feed" : "Αναίρεση διαγραφής ροής",
    "Rename" : "Μετονομασία",
    "Menu" : "Μενού",
    "Mark read" : "Σημείωση ως ανεγνωσμένου",
    "Unpin from top" : "Ξεκαρφίτσωμα από την κορυφή",
    "Pin to top" : "Καρφίτσωμα στην κορυφή",
    "Newest first" : "Νεότερο πρώτα",
    "Oldest first" : "Παλαιότερο πρώτα",
    "Default order" : "Προεπιλεγμένη σειρά",
    "Enable full text" : "Ενεργοποίηση πλήρους κειμένου",
    "Disable full text" : "Απενεργοποίηση πλήρους κειμένου",
    "Unread updated" : "Μη αναγνωσμένο ενημερώθηκε",
    "Ignore updated" : "Αγνόηση ενημέρωσης",
    "Open feed URL" : "Ανοίξτε τη διεύθυνση URL ροής",
    "Delete" : "Διαγραφή",
    "Dismiss" : "Αποδέσμευση",
    "Collapse" : "Σύμπτυξη",
    "Deleted folder" : "Διαγραφή φακέλου",
    "Undo delete folder" : "Αναίρεση διαγραφής φακέλου",
    "Starred" : "Με αστέρι",
    "Unread articles" : "Μη αναγνωσμένα άρθρα",
    "All articles" : "Όλα τα άρθρα",
    "Settings" : "Ρυθμίσεις",
    "Disable mark read through scrolling" : "Απενεργοποίηση σημείωσης ως διαβασμένων κατά τη κύλιση",
    "Compact view" : "Συμπαγής προβολή",
    "Expand articles on key navigation" : "Ανάπτυξη των άρθρων κατά την πλοήγηση με πλήκτρα",
    "Show all articles" : "Εμφάνιση όλων των άρθρων",
    "Reverse ordering (oldest on top)" : "Ανεστραμμένη ταξινόμηση (παλαιότερα στην κορυφή)",
    "Subscriptions (OPML)" : "Συνδρομές (OPML)",
    "Import" : "Εισαγωγή",
    "Export" : "Εξαγωγή",
    "Error when importing: File does not contain valid OPML" : "Σφάλμα κατά την εισαγωγή: Το αρχείο δεν περιέχει έγκυρο OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Σφάλμα εισαγωγής: Το OPML δεν περιέχει ούτε τροφοδοσίες ούτε φακέλους",
    "Unread/Starred Articles" : "Με αστέρι/Μη αναγνωσμένα Άρθρα",
    "Error when importing: file does not contain valid JSON" : "Σφάλμα κατά την εισαγωγή: το αρχείο δεν περιέχει έγκυρο JSON",
    "Help" : "Βοήθεια",
    "Keyboard shortcuts" : "Συντομεύσεις πλητρολογίου",
    "Documentation" : "Τεκμηρίωση",
    "Report a bug" : "Αναφορά σφάλματος"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-24.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/el.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Το αίτημα απέτυχε, η σύνδεση στο δίκτυο δεν είναι διαθέσιμη!",
    "Request unauthorized. Are you logged in?" : "Το αίτημα δεν είναι εξουσιοδοτημένο. Είστε συνδεδεμένοι;",
    "Token expired or app not enabled! Reload the page!" : "Η διαδικασία αναγνώρισης τερματίστηκε ή η εφαρμογή δεν είναι ενεργοποιημένη! Επαναφορτώστε τη σελίδα! ",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Εσωτερικό σφάλμα διακομιστή! Παρακαλώ ελέγξτε το αρχείο data/nextcloud.log για περισσότερες πληροφορίες!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Αποτυχία αιτήματος, το Nextcloud είναι προσωρινά σε κατάσταση συντήρησης!",
    "Unread articles" : "Μη αναγνωσμένα άρθρα",
    "News" : "Νέα",
    "Shared with me" : "Διαμοιρασμένα με εμένα",
    "An RSS/Atom feed reader" : "Τροφοδότης ροής RSS/Atom",
    "Use system cron for updates" : "Χρήση του cron του συστήματος για ενημερώσεις",
    "Maximum read count per feed" : "Ο μέγιστος αριθμός διαβασμένων ανά ροή",
    "Maximum redirects" : "Μέγιστος αριθμός ανακατευθύνσεων",
    "How many redirects the feed fetcher should follow." : "Πόσες ανακατευθύνσεις θα μπορεί να ακολουθεί η υπηρεσία ροών.",
    "Feed fetcher timeout" : "Χρόνος λήξης δέκτη ροής",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Μέγιστος χρόνος σε δευτερόλεπτα, αναμονής φόρτωσης μιας ροής RSS ή Atom; εάν χρειαστεί περισσότερο χρόνο η ενημέρωση θα ματαιωθεί.",
    "Explore Service URL" : "URL Υπηρεσίας Εξερεύνησης",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Εάν οριστεί, θα τεθεί η ροή της διεύθυνση URL αυτής της υπηρεσίας στην ουρά, για προβολή στο τμήμα ροών. Για επιστροφή στην προεπιλογή αφήστε το πεδίο κενό.",
    "Update interval" : "Εσωτερική ενημέρωση",
    "Interval in seconds in which the feeds will be updated." : "Διάστημα σε δευτερόλεπτα στο οποίο θα ενημερωθούν τα feeds.",
    "Download" : "Λήψη",
    "Close" : "Κλείσιμο",
    "Subscribe to" : "Εγγραφείτε στο",
    "No articles available" : "Δεν υπάρχουν διαθέσιμα άρθρα",
    "No unread articles available" : "Κανένα αδιάβαστο άρθρο διαθέσιμο",
    "Open website" : "Άνοιγμα ιστοσελίδας",
    "Star article" : "Επισήμανση με αστέρι",
    "Unstar article" : "Αναίρεση επισήμανσης με αστέρι",
    "Keep article unread" : "Διατήρηση άρθρου ως μη αναγνωσμένου",
    "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη αναγνωσμένου",
    "Share" : "Διαμοιρασμός",
    "Username" : "Όνομα χρήστη",
    "No users found" : "Δεν βρέθηκαν χρήστες",
    "by" : "από",
    "from" : "από",
    "shared by" : "σε κοινή χρήση από",
    "Play audio" : "Αναπαραγωγή ήχου",
    "Download audio" : "Λήψη ήχου",
    "Download video" : "Κατεβάστε το βίντεο",
    "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
    "Description" : "Περιγραφή",
    "right" : "δεξιά",
    "Jump to next article" : "Επόμενο άρθρο",
    "left" : "αριστερά",
    "Jump to previous article" : "Προηγούμενο άρθρο",
    "Toggle star article" : "Εναλλαγή επισήμανσης άρθρου με αστέρι",
    "Star article and jump to next one" : "Επισήμανση άρθρου και μετακίνηση στο επόμενο",
    "Toggle keep current article unread" : "Εναλλαγή διατήρισης τρέχοντος άρθρου ως μη αναγνωσμένου",
    "Open article in new tab" : "Άνοιγμα άρθρου σε νέα καρτέλα",
    "Toggle expand article in compact view" : "Εναλλαγή επέκτασης άρθρου στη συμπαγή προβολή",
    "Refresh" : "Ανανέωση ",
    "Load next feed" : "Φόρτωση επόμενης ροής",
    "Load previous feed" : "Φόρτωση προηγούμενης ροής",
    "Load previous folder" : "Φόρτωση προηγούμενου φακέλου",
    "Load next folder" : "Φόρτωση επόμενου φακέλου",
    "Scroll to active navigation entry" : "Κύλιση στην ενεργή είσοδο πλοήγησης ",
    "Mark current article's feed/folder read" : "Σημείωση της ροής/φακέλου του τρέχοντος άρθρου ως αναγνωσμένα",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
    "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα",
    "Subscribe" : "Εγγραφή",
    "Web address" : "Διεύθυνση ιστοσελίδας",
    "Feed exists already!" : "Η ροή υπάρχει ήδη!",
    "Folder" : "Φάκελος",
    "No folder" : "Κανένας φάκελος",
    "New folder" : "Νέος φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "Go back" : "Μετακίνηση πίσω",
    "Folder exists already!" : "Ο φάκελος υπάρχει ήδη!",
    "Credentials" : "Πιστοποιητικά",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Τα διαπιστευτήρια Βασικής Πιστοποίησης HTTP πρέπει να αποθηκεύονται χωρίς κρυπτογράφηση! Όλοι με πρόσβαση στον διακομιστή ή τη βάση δεδομένων θα έχουν πρόσβαση σε αυτά!",
    "Password" : "Κωδικός πρόσβασης",
    "New Folder" : "Νέος φάκελος",
    "Create" : "Δημιουργία",
    "Explore" : "Εξερεύνηση",
    "Update failed more than 50 times" : "Η αποστολή απέτυχε πάνω από 50 φορές",
    "Deleted feed" : "Διαγραφή ροής",
    "Undo delete feed" : "Αναίρεση διαγραφής ροής",
    "Rename" : "Μετονομασία",
    "Menu" : "Μενού",
    "Mark read" : "Σημείωση ως ανεγνωσμένου",
    "Unpin from top" : "Ξεκαρφίτσωμα από την κορυφή",
    "Pin to top" : "Καρφίτσωμα στην κορυφή",
    "Newest first" : "Νεότερο πρώτα",
    "Oldest first" : "Παλαιότερο πρώτα",
    "Default order" : "Προεπιλεγμένη σειρά",
    "Enable full text" : "Ενεργοποίηση πλήρους κειμένου",
    "Disable full text" : "Απενεργοποίηση πλήρους κειμένου",
    "Unread updated" : "Μη αναγνωσμένο ενημερώθηκε",
    "Ignore updated" : "Αγνόηση ενημέρωσης",
    "Open feed URL" : "Ανοίξτε τη διεύθυνση URL ροής",
    "Delete" : "Διαγραφή",
    "Dismiss" : "Αποδέσμευση",
    "Collapse" : "Σύμπτυξη",
    "Deleted folder" : "Διαγραφή φακέλου",
    "Undo delete folder" : "Αναίρεση διαγραφής φακέλου",
    "Starred" : "Με αστέρι",
    "All articles" : "Όλα τα άρθρα",
    "Settings" : "Ρυθμίσεις",
    "Disable mark read through scrolling" : "Απενεργοποίηση σημείωσης ως διαβασμένων κατά τη κύλιση",
    "Compact view" : "Συμπαγής προβολή",
    "Expand articles on key navigation" : "Ανάπτυξη των άρθρων κατά την πλοήγηση με πλήκτρα",
    "Show all articles" : "Εμφάνιση όλων των άρθρων",
    "Reverse ordering (oldest on top)" : "Ανεστραμμένη ταξινόμηση (παλαιότερα στην κορυφή)",
    "Subscriptions (OPML)" : "Συνδρομές (OPML)",
    "Import" : "Εισαγωγή",
    "Export" : "Εξαγωγή",
    "Error when importing: File does not contain valid OPML" : "Σφάλμα κατά την εισαγωγή: Το αρχείο δεν περιέχει έγκυρο OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Σφάλμα εισαγωγής: Το OPML δεν περιέχει ούτε τροφοδοσίες ούτε φακέλους",
    "Unread/Starred Articles" : "Με αστέρι/Μη αναγνωσμένα Άρθρα",
    "Error when importing: file does not contain valid JSON" : "Σφάλμα κατά την εισαγωγή: το αρχείο δεν περιέχει έγκυρο JSON",
    "Help" : "Βοήθεια",
    "Keyboard shortcuts" : "Συντομεύσεις πλητρολογίου",
    "Documentation" : "Τεκμηρίωση",
    "Report a bug" : "Αναφορά σφάλματος"
},
"nplurals=2; plural=(n != 1);");
